@@ -493,7 +493,7 @@ class vmmAddHardware(vmmGObjectUI):
     def populate_graphics_model(self, model):
         model.clear()
         model.append([_("VNC server"), "vnc"])
-        model.append([_("SPICE server"), "spice"])
+        model.append([_("Spice server"), "spice"])
         model.append([_("Local SDL window"), "sdl"])
 
     def populate_host_device_model(self, devtype, devcap, subtype, subcap):
@@ -1003,9 +1003,9 @@ class vmmAddHardware(vmmGObjectUI):
 
                 if do_exist and not ret:
                     do_use = self.err.yes_no(
-                        _("The following path already exists, but is not\n"
+                        _("The following storage already exists, but is not\n"
                           "in use by any virtual machine:\n\n%s\n\n"
-                          "Would you like to use this path?") % ideal)
+                          "Would you like to reuse this storage?") % ideal)
 
                     if do_use:
                         diskpath = ideal
