@@ -748,8 +748,36 @@ class vmmConnection(vmmGObject):
 
         return net
 
+    def rename_vm(self, domainobj, origxml, newxml):
+        # Undefine old domain
+        domainobj.delete()
+        domainobj.release_handle()
+
+        newobj = None
+        try:
+            try:
+                # Redefine new domain
+                newobj = self.define_domain(newxml)
+            except Exception, renameerr:
+                try:
+                    logging.exception("Error defining new name XML")
+                    newobj = self.define_domain(origxml)
+                except Exception, fixerr:
+                    logging.exception("Failed to redefine original domain!")
+                    raise RuntimeError(
+                        _("Domain rename failed. Attempting to recover also "
+                          "failed.\n\n"
+                          "Original error: %s\n\n"
+                          "Recover error: %s" %
+                          (str(renameerr), str(fixerr))))
+                raise
+        finally:
+            if newobj:
+                # Reinsert handle into new domain
+                domainobj.change_name_backend(newobj)
+
     def define_domain(self, xml):
-        self.vmm.defineXML(xml)
+        return self.vmm.defineXML(xml)
     def define_interface(self, xml):
         self.vmm.interfaceDefineXML(xml, 0)
 
@@ -833,11 +861,16 @@ class vmmConnection(vmmGObject):
             return
 
         self.vmm = None
-        self.nets = {}
+        self.nodedevs = {}
+        self.netdevs = {}
+        self.mediadevs = {}
+        self.interfaces = {}
         self.pools = {}
+        self.nets = {}
         self.vms = {}
         self.activeUUIDs = []
         self.record = []
+
         self._change_state(self.STATE_DISCONNECTED)
 
     def _open_dev_conn(self, uri):
